//+------------------------------------------------------------------+
//|                                                   DailyTrade.mq4 |
//|                                       Copyright  2006, firedave | 
//|                                        http://www.fx-review.com/ | 
//+------------------------------------------------------------------+


extern string  
         Expert_Name       = "---------- Daily Trade base on PEDRO.mql";
extern double 
         StopLoss          = 30,
         TakeProfit        = 25,
         TrailingStop      = 25;
         
extern string  
         Time_Parameters   = "---------- EA Active Time";
extern int     
         StartHour         = 10,
         EndHour           = 11;
         
extern string  
         MM_Parameters     = "---------- MoneyManagement by L.Williams";
extern double 
         Lots              = 1;
extern bool 
         MM                = true, //Use Money Management or not
         AccountIsMicro    = false; //Use Micro-Account or not
extern int 
         Risk              = 10; //10%

extern bool 
         Show_Settings     = true;

//---- Global varaibles
static int 
         TimeFrame         = 0;

string
         TicketComment     = "DailyTrade v0.1";

int
         MagicNumber       = 20060406;



//+------------------------------------------------------------------+
//| expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
  {
//---- 
//   if(Show_Settings) Print_Details();
//   else Comment("");
//----
   
   return(0);
  }
//+------------------------------------------------------------------+
//| expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
  {
//----
      TimeFrame=Period(); //Prevent counting the cross while the user changing the timeframe
//----
   return(0);
  }


//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int start()
{

   double 
         Entry,
         ReEntry;
                  
   int   
         GAP               = 5,
         ReEntryGAP        = 5,
         MaxTrade          = 3,
         Direction         = 0,
         cnt,
         ticket,
         total;
         
         
// initial data checks
// it is important to make sure that the expert works with a normal
// chart and the user did not make any mistakes setting external 
// variables (Lots, StopLoss, TakeProfit, 
// TrailingStop) in our case, we check TakeProfit
// on a chart of less than 100 bars

   if(Bars<100)
     {
      Print("bars less than 100");
      return(0);  
     }

   if(TakeProfit<10)
     {
      Print("TakeProfit less than 10");
      return(0);  // check TakeProfit
     }

   if(StopLoss<=0)
     {
      Print("StopLoss less or equal than 0");
      return(0);  // check StopLoss
     }

   if(MM==true) Lots = subLotSize(); //Adjust the lot size

//   total = TotalTrade(MagicNumber); // Total Oder base on MagicNumber and Symbol
   total = OrdersTotal();
      
// TRAILING STOP
   if (TrailingStop > 0)
   {
      for(cnt=0;cnt<total;cnt++)
      {
         OrderSelect(cnt, SELECT_BY_POS, MODE_TRADES);

         if(OrderType()<=OP_SELL &&
            OrderSymbol()==Symbol() &&
            OrderMagicNumber()==MagicNumber)
         {
            if(OrderType()==OP_BUY)   // long position is opened
            {
               if(Bid-OrderOpenPrice()>Point*TrailingStop &&
                  OrderStopLoss()<Bid-Point*TrailingStop)
               {
                  OrderModify(OrderTicket(),OrderOpenPrice(),Bid-Point*TrailingStop,OrderTakeProfit(),0,Green);
                  return(0);
               }
            }
            else // go to short position
            {
               if(OrderOpenPrice()-Ask>Point*TrailingStop)
               {
               if(OrderStopLoss()>Ask+Point*TrailingStop || OrderStopLoss()==0)
               {
                  OrderModify(OrderTicket(),OrderOpenPrice(),Ask+Point*TrailingStop,OrderTakeProfit(),0,Red);
                  return(0);
               }
               }
            }
         }
      }
   }


// SET Entry TO ZERO BETWEEN 10 AND 11
   if(Hour()<StartHour || Hour()>EndHour) 
   {
      Entry = 0;
      return(0);
   }


// CHECK FOR MAXIMUM TRADE
   total = subTotalTrade(); // Total Oder base on MagicNumber and Symbol
   if(total>=MaxTrade) return(0);
   
   
// ENTRY
   if(Entry > 0) 
   {
      if(Ask>=Entry+GAP*Point)
      {
         ticket=OrderSend(Symbol(),OP_BUY,Lots,Ask,3,Ask-StopLoss*Point,Ask+TakeProfit*Point,TicketComment,MagicNumber,0,Green);
         if(ticket>0)
           {
            if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES)) Print("BUY order opened : ",OrderOpenPrice());
           }
         else Print("Error opening BUY order : ",GetLastError()); 
         
         ReEntry     = Ask;
         Entry       = 0;
         Direction   = 1;
         Print("ReEntry ",ReEntry, " Time ",TimeToStr(CurTime(),TIME_DATE|TIME_MINUTES));

         return(0); 
      }

      if(Ask<=Entry-GAP*Point)
      {
         ticket=OrderSend(Symbol(),OP_SELL,Lots,Bid,3,Bid+StopLoss*Point,Bid-TakeProfit*Point,TicketComment,MagicNumber,0,Red);
         if(ticket>0)
           {
            if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES)) Print("SELL order opened : ",OrderOpenPrice());
           }
         else Print("Error opening SELL order : ",GetLastError()); 

         ReEntry     = Ask;
         Entry       = 0;
         Direction   = 2;
         Print("ReEntry ",ReEntry, " Time ",TimeToStr(CurTime(),TIME_DATE|TIME_MINUTES));

         return(0); 
      
      }

   } else
   {
      if(total==0)
      {
         Entry       = Ask;
         ReEntry     = 0;
         Print("Entry ",Entry, " Time ",TimeToStr(CurTime(),TIME_DATE|TIME_MINUTES));
      }
   }
   
   if(ReEntry >0)
   {
      if(Ask>=ReEntry+ReEntryGAP*Point &&
         Direction==1)   
      {
         ticket=OrderSend(Symbol(),OP_BUY,Lots,Ask,3,Ask-StopLoss*Point,Ask+TakeProfit*Point,TicketComment,MagicNumber,0,Green);
         if(ticket>0)
           {
            if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES)) Print("BUY order opened : ",OrderOpenPrice());
           }
         else Print("Error opening BUY order : ",GetLastError()); 
         
         if(total+1<MaxTrade) ReEntry = Ask; else ReEntry = 0;
         Print("ReEntry ",ReEntry, " Time ",TimeToStr(CurTime(),TIME_DATE|TIME_MINUTES));

         return(0); 
      }

      if(Ask<=ReEntry-ReEntryGAP*Point &&
         Direction==2)
      {
         ticket=OrderSend(Symbol(),OP_SELL,Lots,Bid,3,Bid+StopLoss*Point,Bid-TakeProfit*Point,TicketComment,MagicNumber,0,Red);
         if(ticket>0)
           {
            if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES)) Print("SELL order opened : ",OrderOpenPrice());
           }
         else Print("Error opening SELL order : ",GetLastError()); 

         if(total+1<MaxTrade) ReEntry = Ask; else ReEntry = 0;
         Print("ReEntry ",ReEntry, " Time ",TimeToStr(CurTime(),TIME_DATE|TIME_MINUTES));

         return(0); 
      
      }
   
   }         

}
// END PROGRAM

//+------------------------------------------------------------------+
//| FUNCTION DEFINITIONS
//+------------------------------------------------------------------+

// MONEY MANAGEMENT FUNCTION  
double subLotSize()
{
     double lotMM = MathCeil(AccountFreeMargin() *  Risk / 1000) / 100;
	  
	  if(AccountIsMicro==false) //normal account
	  {
	     if (lotMM < 0.1) lotMM = Lots;
	     if ((lotMM > 0.5) && (lotMM < 1)) lotMM=0.5;
	     if (lotMM > 1.0) lotMM = MathCeil(lotMM);
	     if  (lotMM > 100) lotMM = 100;
	  }
	  else //micro account
	  {
	     if (lotMM < 0.01) lotMM = Lots;
	     if (lotMM > 1.0) lotMM = MathCeil(lotMM);
	     if  (lotMM > 100) lotMM = 100;
	  }
	  
	  return (lotMM);
}

// NUMBER OF ORDER BASE ON SYMBOL AND MAGICNUMBER
int subTotalTrade() {
   int
      cnt, 
      total;
   for(cnt=0;cnt<OrdersTotal();cnt++){
      if(OrderSelect(cnt,SELECT_BY_POS)){
         if(OrderSymbol()==Symbol() && OrderMagicNumber()==MagicNumber){
            total++;
         }
      }
   }
   return(total);
}

// END FUNCTION